@@ -309,8 +309,9 @@ def _get_measure(obj: Union[DataArray, Dataset], key: str) -> List[str]:
     results = set()
     for var in obj.variables:
         da = obj[var]
-        if "cell_measures" in da.attrs:
-            attr = da.attrs["cell_measures"]
+        attrs_or_encoding = ChainMap(da.attrs, da.encoding)
+        if "cell_measures" in attrs_or_encoding:
+            attr = attrs_or_encoding["cell_measures"]
             measures = parse_cell_methods_attr(attr)
             if key in measures:
                 results.update([measures[key]])
@@ -339,8 +340,9 @@ def _get_bounds(obj: Union[DataArray, Dataset], key: str) -> List[str]:
 
     results = set()
     for var in apply_mapper(_get_all, obj, key, error=False, default=[key]):
-        if "bounds" in obj[var].attrs:
-            results |= {obj[var].attrs["bounds"]}
+        attrs_or_encoding = ChainMap(obj[var].attrs, obj[var].encoding)
+        if "bounds" in attrs_or_encoding:
+            results |= {attrs_or_encoding["bounds"]}
 
     return list(results)
 
@@ -627,8 +629,10 @@ def _getitem(
         # actual variable. It seems practical to ignore them when indexing
         # with a scalar key. Hopefully these will soon get decoded to IntervalIndex
         # and we can move on...
-        if scalar_key:
-            bounds = {obj[k].attrs.get("bounds", None) for k in names}
+        if not isinstance(obj, DataArray) and scalar_key:
+            bounds = set()
+            for name in names:
+                bounds.update(obj.cf.bounds.get(name, []))
             names = set(names) - bounds
         return names
 
@@ -1025,6 +1029,10 @@ class CFAccessor:
             mapped_test_elements.append(flag_dict[elem])
         return self._obj.isin(mapped_test_elements)
 
+    def _drop_missing_variables(self, variables: List[str]) -> List[str]:
+
+        return [var for var in variables if var in self._obj or var in self._obj.coords]
+
     def _get_all_cell_measures(self):
         """
         Get all cell measures defined in the object, adding CF pre-defined measures.
@@ -1364,18 +1372,24 @@ class CFAccessor:
         """
 
         obj = self._obj
-        all_attrs = [da.attrs.get("cell_measures", "") for da in obj.coords.values()]
+        all_attrs = [
+            ChainMap(da.attrs, da.encoding).get("cell_measures", "")
+            for da in obj.coords.values()
+        ]
         if isinstance(obj, DataArray):
-            all_attrs += [obj.attrs.get("cell_measures", "")]
+            all_attrs += [ChainMap(obj.attrs, obj.encoding).get("cell_measures", "")]
         elif isinstance(obj, Dataset):
             all_attrs += [
-                da.attrs.get("cell_measures", "") for da in obj.data_vars.values()
+                ChainMap(da.attrs, da.encoding).get("cell_measures", "")
+                for da in obj.data_vars.values()
             ]
 
         keys = {}
         for attr in all_attrs:
             keys.update(parse_cell_methods_attr(attr))
-        measures = {key: _get_all(self._obj, key) for key in keys}
+        measures = {
+            key: self._drop_missing_variables(_get_all(self._obj, key)) for key in keys
+        }
 
         return {k: sorted(set(v)) for k, v in measures.items() if v}
 
@@ -1869,9 +1883,15 @@ class CFDatasetAccessor(CFAccessor):
         Property that returns a dictionary
             {parametric_coord_name: {standard_term_name: variable_name}}
         """
-        return {
-            dim: self._obj[dim].cf.formula_terms for dim in _get_dims(self._obj, "Z")
-        }
+        results = {}
+        for dim in _get_dims(self._obj, "Z"):
+            terms = self._obj[dim].cf.formula_terms
+            variables = self._drop_missing_variables(list(terms.values()))
+            terms = {key: val for key, val in terms.items() if val in variables}
+            if terms:
+                results[dim] = terms
+
+        return results
 
     @property
     def bounds(self) -> Dict[str, List[str]]:
@@ -1888,12 +1908,15 @@ class CFDatasetAccessor(CFAccessor):
         keys = self.keys() | set(obj.variables)
 
         vardict = {
-            key: apply_mapper(_get_bounds, obj, key, error=False) for key in keys
+            key: self._drop_missing_variables(
+                apply_mapper(_get_bounds, obj, key, error=False)
+            )
+            for key in keys
         }
 
         return {k: sorted(v) for k, v in vardict.items() if v}
 
-    def get_bounds(self, key: str) -> DataArray:
+    def get_bounds(self, key: str) -> Union[DataArray, Dataset]:
         """
         Get bounds variable corresponding to key.
 
@@ -1907,7 +1930,11 @@ class CFDatasetAccessor(CFAccessor):
         DataArray
         """
 
-        return apply_mapper(_variables(_single(_get_bounds)), self._obj, key)[0]
+        results = self.bounds.get(key, [])
+        if not results:
+            raise KeyError(f"No results found for {key!r}.")
+
+        return self._obj[results[0] if len(results) == 1 else results]
 
     def get_bounds_dim_name(self, key: str) -> str:
         """
@@ -2144,12 +2171,13 @@ class CFDataArrayAccessor(CFAccessor):
             {parametric_coord_name: {standard_term_name: variable_name}}
         """
         da = self._obj
-        if "formula_terms" not in da.attrs:
+        if "formula_terms" not in ChainMap(da.attrs, da.encoding):
             var = da[_single(_get_dims)(da, "Z")[0]]
         else:
             var = da
+
         terms = {}
-        formula_terms = var.attrs.get("formula_terms", "")
+        formula_terms = ChainMap(var.attrs, var.encoding).get("formula_terms", "")
         for mapping in re.sub(r"\s*:\s*", ":", formula_terms).split():
             key, value = mapping.split(":")
             terms[key] = value
