@@ -16,6 +16,7 @@ from cf_xarray.utils import parse_cf_standard_name_table
 
 from ..datasets import (
     airds,
+    ambig,
     anc,
     basin,
     ds_no_attrs,
@@ -24,6 +25,7 @@ from ..datasets import (
     multiple,
     popds,
     romsds,
+    vert,
 )
 from . import raise_if_dask_computes, requires_pint
 
@@ -175,7 +177,7 @@ def test_cell_measures():
     ds["air"].attrs["cell_measures"] += " volume: foo"
     ds["foo"].attrs["cell_measures"] = ds["air"].attrs["cell_measures"]
     expected = dict(area=["cell_area"], foo_measure=["foo"], volume=["foo"])
-    actual_air = ds["air"].cf.cell_measures
+    actual_air = ds.cf["air"].cf.cell_measures
     actual_foo = ds.cf["foo_measure"].cf.cell_measures
     assert actual_air == actual_foo == expected
 
@@ -211,6 +213,30 @@ def test_standard_names():
     assert dsnew.cf.standard_names == dict(a=["a", "b"])
 
 
+def test_drop_bounds():
+    assert ambig.cf["latitude"].name == "lat"
+    assert ambig.cf["longitude"].name == "lon"
+    assert ambig.cf.bounds["latitude"] == ["vertices_latitude"]
+    assert ambig.cf.bounds["longitude"] == ["vertices_longitude"]
+
+
+def test_accessor_getattr_and_describe():
+    ds_verta = vert.set_coords(
+        (
+            "ps",
+            "areacella",
+        )
+    )
+    ds_vertb = xr.decode_cf(vert, decode_coords="all")
+
+    assert ds_verta.cf.cell_measures == ds_vertb.cf.cell_measures
+    assert ds_verta.o3.cf.cell_measures == ds_vertb.o3.cf.cell_measures
+    assert ds_verta.cf.formula_terms == ds_vertb.cf.formula_terms
+    assert ds_verta.o3.cf.formula_terms == ds_vertb.o3.cf.formula_terms
+    assert ds_verta.cf.bounds == ds_vertb.cf.bounds
+    assert str(ds_verta.cf) == str(ds_vertb.cf)
+
+
 def test_getitem_standard_name():
     actual = airds.cf["air_temperature"]
     expected = airds["air"]
@@ -1425,3 +1451,24 @@ def test_flag_errors():
 
     with pytest.raises(ValueError):
         basin.cf == "pacific_ocean"
+
+
+def test_missing_variables():
+
+    # Bounds
+    ds = mollwds.copy(deep=True)
+    ds = ds.drop("lon_bounds")
+    assert ds.cf.bounds == {"lat": ["lat_bounds"], "latitude": ["lat_bounds"]}
+
+    with pytest.raises(KeyError, match=r"No results found for 'longitude'."):
+        ds.cf.get_bounds("longitude")
+
+    # Cell measures
+    ds = airds.copy(deep=True)
+    ds = ds.drop("cell_area")
+    assert ds.cf.cell_measures == {}
+
+    # Formula terms
+    ds = vert.copy(deep=True)
+    ds = ds.drop("ap")
+    assert ds.cf.formula_terms == {"lev": {"b": "b", "ps": "ps"}}
